# -*- coding: utf-8 -*-
from setuphelpers import *

"""
Please read the documentation.

Documentation (EN): https://www.wapt.fr/en/doc/wapt-replication.html
Documentation (FR): https://www.wapt.fr/fr/doc/wapt-replication.html

Parameters: https://www.wapt.fr/en/doc/wapt-replication.html#wapt-agent-configuration

Examples:

"enable_remote_repo": True,
# Active sync / Default value : False

"local_repo_path": None,
# Path where the sync is / Default value : "<wapt_path>/repository" / Example value : "/var/www/html/" for a linux

"local_repo_sync_task_period": None,
# Synchronization is started periodically so select a period / Default value : '10m' for 10 minutes / Example value : '1d' for one sync by day it's 's' for seconds,'m' for minutes,'h' for hours,'d' for day, 'w' for weeks

"local_repo_time_for_sync_start": None,
# Sync will start only after this hour of the day / Default value : None / Example value : '23:00' for sync to be done only after 11PM (it's in format : HH:MM)

"local_repo_time_for_sync_end": None,
# Sync will stop after this hour of the day / Default value : None if no 'local_repo_time_for_sync_start' configured else 'local_repo_time_for_sync_start' + 1 hour / Example value : '01:00' with previous example sync will be done every day only between 23PM and 01AM

"local_repo_limit_bandwidth": None,
# Limit for bandwidth to use for repo sync in Mbits/s / Default value : None / Example value :  0.5 for 0.5 Mbits/s (=500KBits/s)

"remote_repo_dirs": None,
# Select what do you want to sync in wapt packages ('wapt'), host packages ('wapt-host') or/and windows-updates ('waptwua') / Default value : "wapt,waptwua" / Example value : "wapt,waptwua,wapt-host"

"""


def install():
    # inifile_deletesection(WAPT.config_filename, "repo-sync") # UNCOMMENT = FORCE CONF

    # You can reset a parameter to its default value by setting it to None.
    conf = {
        "enable_remote_repo": True,
    }

    for akey in conf:
        if conf[akey] is not None:
            inifile_writestring(WAPT.config_filename, "repo-sync", akey, conf[akey])
        if conf[akey] is None:
            if inifile_hasoption(inifilename, "repo-sync", conf[akey]):
                inifile_deleteoption(inifilename, "repo-sync", conf[akey])

    print("Reloading WAPT configuration")
    WAPT.reload_config_if_updated()


def uninstall():
    # Delete synced files - UNCOMMENT IF NEEDED
    # remove_tree(
    #     inifile_readstring(WAPT.config_filename, "repo-sync", "local_repo_path") or makepath(WAPT.wapt_base_dir, "repository"), ignore_errors=True
    # )

    inifile_deletesection(WAPT.config_filename, "repo-sync")

    print("Reloading WAPT configuration")
    WAPT.reload_config_if_updated()
